function LootSquid:TestRunAll()

    --[[ add tests here ]]--
    local tests = {
        ["TestOnChatMessage"] = self.TestOnChatMessage
    }



    --[[ setup ]]--
    LootSquid.debug.alwaysParseLoot = true
    LootSquid.debug.alwaysParseChat = true
    LootSquid.debug.bypassSafeCalls = true
    LootSquid.debug.disableWhispers = true
    LootSquid.debug.logging = true
    LootSquid.session.currentLootSlot = 1




    --[[ run all tests ]]--
    LootSquid:OpenLootGui()

    local totalTestsSuccess = 0
    local totalTestsFail = 0

    for k,v in pairs(tests) do
        local success, error = pcall(v)
        local functionName = tostring(k)
        if not success then
            totalTestsFail = totalTestsFail + 1
            LootSquid:LogError(
                "Test failed. Name: "..functionName
                        ..", Error: "..tostring(error)
            )
        else
            totalTestsSuccess = totalTestsSuccess + 1
            LootSquid:LogInfo(
                string.format("|cFF00FF00%s:|r ", "Test succeeded") .. "Name: "..functionName
            )
        end
    end

    local totalTests = totalTestsFail + totalTestsSuccess

    if totalTestsFail > 0 then
        LootSquid:LogError(
            string.format("|cFFFF0000%s:|r ", "Test summary. ")
                    ..tostring(totalTestsFail)
                    .." out of "
                    ..tostring(totalTests)
                    .." failed."
        )
    else
        LootSquid:LogInfo(
            string.format("|cFF00FF00%s:|r ", "Test summary. ")
                    ..tostring(totalTestsSuccess)
                    .." out of "
                    ..tostring(totalTests)
                    .." succeeded."
        )
    end

    --[[ clean up ]]--
--    LootSquid.debug.alwaysParseLoot = false
--    LootSquid.debug.alwaysParseChat = false
--    LootSquid.debug.bypassSafeCalls = false
--    LootSquid.debug.disableWhispers = false
--    LootSquid.debug.logging = false
--    LootSquid.session.currentLootSlot = 0
end

function LootSquid:TestOnChatMessage()

    local messages = {
        -- player
        {
            sender = UnitName("player"),
            message = "!need |cff9d9d9d|Hitem:7073:0:0:0:0:0:0:0:80:0:0|h[Broken Fang]|h|r"
        },
        -- need with spaces
        {
            sender = "zGoolt",
            message = "!need         |cff9d9d9d|Hitem:113595:0:0:0:0:0:0:0:100:0:3:0|h[Treads of Sand and Blood]|h|r"
        },

        -- need with no space
        {
            sender = "zHanslock",
            message = "!need|cff9d9d9d|Hitem:113592:0:0:0:0:0:0:0:100:0:3:0|h[Bileslinger's Censer]|h|r"
        },

        -- need with unneeded characters
        {
            sender = "zFnitzer",
            message = "!need dgd |cff9d9d9d|Hitem:113612:0:0:0:0:0:0:0:100:0:3:1:560|h[Scales of Doom]|h|r"
        },

        -- need from other realm
        {
            sender = "zZulgarip-Dentarg",
            message = "!need |cff9d9d9d|Hitem:113641:0:0:0:0:0:0:0:100:0:3:0|h[Living Mountain Shoulderguards]|h|r"
        },

        -- first need
        {
            sender = "zZayne",
            message = "!need |cff9d9d9d|Hitem:113838:0:0:0:0:0:0:0:100:0:3:0|h[Gar'tash, Hammer of the Breakers]|h|r"
        },

        -- then change to greed
        {
            sender = "zZayne",
            message = "!greed |cff9d9d9d|Hitem:113838:0:0:0:0:0:0:0:100:0:3:0|h[Gar'tash, Hammer of the Breakers]|h|r"
        },

        -- and an actual greed
        {
            sender = "zElizx",
            message = "!greed |cff9d9d9d|Hitem:113857:0:0:0:0:0:0:0:100:0:3:0|h[Staff of the Grand Imperator]|h|r"
        },

        -- greed with no link (which should replace the linked item with no item at all)
        {
            sender = "zElizx",
            message = "!greed"
        },
    }

    for k,v in pairs(messages) do
        LootSquid:OnChatMessage(v.message, v.sender)
    end

    -- all events will be processed on next update, hence there is no difference in time. we fix by altering update time
    LootSquid.lastChatRequestEventTime = GetTime() + 1.0
end
